%bcond_with manifold_testing
%bcond_without python_bindings

%define major     3
%define libname   %mklibname %{name} %{major}
%define libname_c %mklibname %{name}c %{major}
%define devname   %mklibname %{name} -d

Name:           manifold
Version:        3.2.0
Release:        %mkrel 1
Summary:        Geometry library for topological robustness
License:        Apache-2.0
Group:          System/Libraries
URL:            https://github.com/elalish/manifold
Source0:        https://github.com/elalish/manifold/releases/download/v%{version}/%{name}-%{version}.tar.gz
BuildRequires:  cmake
BuildRequires:  openvdb-devel >= 11
BuildRequires:  cmake(Clipper2)
BuildRequires:  cmake(TBB)
BuildRequires:  cmake(assimp)
BuildRequires:  pkgconfig(gtest)
%if %{with python_bindings}
BuildRequires:  python3-nanobind-devel
%endif

%description
Manifold is a geometry library dedicated to creating and operating on manifold
triangle meshes. A manifold mesh is a mesh that represents a solid object, and
so is very important in manufacturing, CAD, structural analysis, etc. Manifold
also supports arbitrary vertex properties and enables mapping of materials for
rendering use-cases. Our primary goal is reliability: guaranteed manifold
output without caveats or edge cases. Our secondary goal is performance:
efficient algorithms that make extensive use of parallelization, or pipelining
when only a single thread is available.

%package -n %{libname}
Summary:        Geometry library for topological robustness
Group:          System/Libraries

%description -n %{libname}
Manifold is a geometry library dedicated to creating and operating on manifold
triangle meshes. A manifold mesh is a mesh that represents a solid object, and
so is very important in manufacturing, CAD, structural analysis, etc. Manifold
also supports arbitrary vertex properties and enables mapping of materials for
rendering use-cases. Our primary goal is reliability: guaranteed manifold
output without caveats or edge cases. Our secondary goal is performance:
efficient algorithms that make extensive use of parallelization, or pipelining
when only a single thread is available.

%package -n %{libname_c}
Summary:        Geometry library for topological robustness
Group:          System/Libraries

%description -n %{libname_c}
Manifold is a geometry library dedicated to creating and operating on manifold
triangle meshes. A manifold mesh is a mesh that represents a solid object, and
so is very important in manufacturing, CAD, structural analysis, etc. Manifold
also supports arbitrary vertex properties and enables mapping of materials for
rendering use-cases. Our primary goal is reliability: guaranteed manifold
output without caveats or edge cases. Our secondary goal is performance:
efficient algorithms that make extensive use of parallelization, or pipelining
when only a single thread is available.

%package -n %{devname}
Summary:        Development files for manifold
Group:          Development/C++
Requires:       %{libname} = %{version}-%{release}
Requires:       %{libname_c} = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}
Requires:       cmake(Clipper2)
Requires:       cmake(assimp)

%description -n %{devname}
Header files for development with %{name}.

%package -n python3-manifold
Summary:        Python bindings for manifold
Group:          Development/Python

%description -n python3-manifold
Manifold is a geometry library dedicated to creating and operating on manifold
triangle meshes. A manifold mesh is a mesh that represents a solid object, and
so is very important in manufacturing, CAD, structural analysis, etc. Manifold
also supports arbitrary vertex properties and enables mapping of materials for
rendering use-cases. Our primary goal is reliability: guaranteed manifold
output without caveats or edge cases. Our secondary goal is performance:
efficient algorithms that make extensive use of parallelization, or pipelining
when only a single thread is available.

%prep
%autosetup -p1

%build
%cmake \
  -DMANIFOLD_USE_BUILTIN_manifold:BOOL=OFF \
  -DMANIFOLD_EXPORT:BOOL=ON \
  -DMANIFOLD_PAR:BOOL=ON \
  %if %{with python_bindings}
  -DMANIFOLD_PYBIND:BOOL=ON \
  %else
  -DMANIFOLD_PYBIND:BOOL=OFF \
  %endif
  -DMANIFOLD_CBIND:BOOL=ON
%cmake_build

%install
%cmake_install

%if %{with manifold_testing}
%check
%ctest
%endif

%files -n %{libname}
%license LICENSE
%{_libdir}/libmanifold.so.%{major}{,.*}

%files -n %{libname_c}
%license LICENSE
%{_libdir}/libmanifoldc.so.%{major}{,.*}

%files -n %{devname}
%license LICENSE
%doc README.md CONTRIBUTING.md
%{_libdir}/libmanifold.so
%{_libdir}/libmanifoldc.so
%{_includedir}/manifold/
%{_libdir}/cmake/manifold/
%{_libdir}/pkgconfig/manifold.pc

%if %{with python_bindings}
%files -n python3-manifold
%license LICENSE
%{python3_sitearch}/manifold3d.*.so
%{python3_sitearch}/manifold3d.pyi
%endif


%changelog
* Sat Jul 26 2025 daviddavid <daviddavid> 3.2.0-1.mga10
+ Revision: 2259602
- initial package manifold

